// src/components/ItemDetails.js
import React, { useState, useEffect } from 'react';
import { TextField, Button, Container, Avatar } from '@mui/material';
import axios from 'axios';

export default function ItemDetails({ item, token, onSave }) {
  const [name, setName] = useState(item.name);
  const [description, setDescription] = useState(item.description);
  const [imagePath, setImagePath] = useState(item.image_path || '');
  const [imageSrc, setImageSrc] = useState('/images/default.jpg'); // Initial default image

  useEffect(() => {
    // Function to fetch image similar to getImageSrc in Items.js
    const getImageSrc = (itemId) => {
      return axios.get(`${process.env.REACT_APP_API_URL}/items/${itemId}/image`, {
        headers: { Authorization: `Bearer ${token}` },
        responseType: 'blob'
      })
      .then(response => {
        if (response.status === 200) {
          return new Promise((resolve, reject) => {
            const reader = new FileReader();
            reader.onload = () => resolve(reader.result);
            reader.onerror = reject;
            reader.readAsDataURL(response.data);
          });
        } else {
          throw new Error('Image fetch failed');
        }
      })
      .catch(() => {
        // Return the data URL of the default image if image fetch fails
        return new Promise((resolve, reject) => {
          const img = new Image();
          img.src = '/default.jpg'; 
          img.onload = () => {
            const canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            const ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            const dataURL = canvas.toDataURL();
            resolve(dataURL);
          };
          img.onerror = reject;
        });
      });
    };

    // Fetch the image when the component mounts or the item changes
    getImageSrc(item.ID).then(dataUrl => setImageSrc(dataUrl));
  }, [item.ID, token]);

  const handleSave = () => {
    axios.put(`${process.env.REACT_APP_API_URL}/items/${item.ID}`, 
      { name, description, image_path: imagePath },
      {
        headers: { Authorization: `Bearer ${token}` }
      }
    ).then(() => {
      onSave(); // Notify parent to refresh items
    });
  };

  const handleImageError = (e) => {
    e.target.src = '/images/default.jpg'; // Fallback to default image on error
  };

  return (
    <Container>
      <h3>Edit Item: {item.name}</h3>

      {/* Display the item image as an avatar */}
      <Avatar
        src={imageSrc}
        alt={name}
        onError={handleImageError}
        sx={{ width: 100, height: 100, marginBottom: '16px' }} // Style the Avatar
      />

      <TextField
        label="Item Name"
        variant="outlined"
        fullWidth
        margin="normal"
        value={name}
        onChange={(e) => setName(e.target.value)}
      />
      <TextField
        label="Item Description"
        variant="outlined"
        fullWidth
        margin="normal"
        value={description}
        onChange={(e) => setDescription(e.target.value)}
      />
      <TextField 
        label="Item Image Path" 
        variant="outlined" 
        fullWidth 
        margin="normal"
        value={imagePath}
        onChange={(e) => setImagePath(e.target.value)} 
      />
      <Button variant="contained" color="primary" onClick={handleSave}>
        Save Changes
      </Button>
    </Container>
  );
}